@@ -1,6 +1,6 @@
 context("Check prediction_breakdown() function")
 
-new_apartments <- apartmentsTest[1001, -1]
+new_apartments <- apartments_test[1001, -1]
 pb_lm <- prediction_breakdown(explainer_regr_lm, observation = new_apartments)
 pb_rf <- prediction_breakdown(explainer_regr_rf, observation = new_apartments)
 
